Summary: A library of functions for manipulating TIFF format image files.
Name: libtiff
Version: 3.7.3
Release: 4tr
License: distributable
Group: Trustix Official
Source0: ftp://ftp.remotesensing.org/pub/libtiff/tiff-%{version}.tar.gz
Patch6: libtiff-v3.5.7-seek.patch
Patch7: libtiff-v3.5.7-exit.patch
Patch8: libtiff-CVE-2005-2024_5_6.patch
Patch9: libtiff-CVE-2005-2120.patch
Patch10: libtiff-CVE-2006-2193.patch
Patch11: libtiff-CVE-2006-2656.patch
Patch12: libtiff-3.7.3-overflow.patch
URL: http://www.libtiff.org/
BuildRoot: %{_tmppath}/%{name}-root
BuildRequires: zlib-devel zlib libjpeg-devel libjpeg
Requires: zlib libjpeg 
%define LIBVER %(echo %{version} | cut -f-2 -d.)

%description
The libtiff package contains a library of functions for manipulating 
TIFF (Tagged Image File Format) image format files.  TIFF is a widely
used file format for bitmapped images.  TIFF files usually end in the
.tif extension and they are often quite large.

The libtiff package should be installed if you need to manipulate TIFF
format image files.

%package devel
Summary: Development tools for programs which will use the libtiff library.
Group: Trustix Official
Requires: libtiff = %{version}

%description devel
This package contains the header files and static libraries for
developing programs which will manipulate TIFF format image files
using the libtiff library.

If you need to develop programs which will manipulate TIFF format
image files, you should install this package.  You'll also need to
install the libtiff package.

%prep
%setup -q -n tiff-%{version}
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p0
%patch10 -p1
%patch11 -p1
%patch12 -p1

find . -type d -name CVS | xargs -r rm -frv

%build

./configure --prefix=/usr --mandir=%{_mandir} --enable-lzw --enable-jpeg
make 
make check 

%install
[ "$RPM_BUILD_DIR" ] && rm -fr $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT  install


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != "/" ] && rm -rf "$RPM_BUILD_ROOT"

%files
%defattr(-,root,root,0755)
%doc COPYRIGHT README VERSION
%{_bindir}/*
%{_libdir}/libtiff.so.*
%{_mandir}/man1/*

%files devel
%defattr(-,root,root,0755)
%doc TODO html
%{_includedir}/*
%{_libdir}/libtiff.so
%{_libdir}/libtiff.a
%{_libdir}/libtiffxx.so.3.7.3
%{_mandir}/man3/*

%changelog
* Thu Aug 03 2006 Nived Gopalan <nived at trustix dot org> 3.7.3-4tr
- SECURITY Fix: Tavis Ormandy, Google Security Team has reported some
  vulnerabilities in libTIFF, which can be exploited by malicious people
  to cause a DoS or potentially compromise a vulnerable system. The
  vulnerabilities are caused due to various heap and integer overflows
  when processing TIFF images and can be exploited via a specially
  crafted TIFF image.

  The Common Vulnerabilities and Exposures project (cve.mitre.org) has
  assigned the names CVE-2006-3459, CVE-2006-3460, CVE-2006-3461,
  CVE-2006-3462, CVE-2006-3463, CVE-2006-3464 and CVE-2006-3465
  these issues.

* Thu Jun 15 2006 Nived Gopalan <nived at trustix dot org> 3.7.3-3tr
- SECURITY Fix: gpe92 has discovered a vulnerability in LibTIFF caused
  due to a boundary error within tiff2pdf when handling a TIFF file with
  a "DocumentName" tag that contains UTF-8 characters. This can be
  exploited to cause a stack-based buffer overflow and may allow
  arbitrary code execution.
- Stack-based buffer overflow in the tiffsplit command in libtiff  might
  allow attackers to execute arbitrary code via a long filename.

  The Common Vulnerabilities and Exposures project (cve.mitre.org) has
  assigned the names CVE-2006-2193 and CVE-2006-2656 these issues.

* Thu May 04 2006 Nived Gopalan <nived at trustix dot org> 3.7.3-2tr
- SECURITY Fix: Tavis Ormandy has reported some vulnerabilities in LibTIFF,
  which can be exploited by malicious people to cause a DoS and potentially
  to compromise a user's system.
- Several unspecified errors in the "TIFFFetchAnyArray()" function and in
  the cleanup functions can be exploited to crash an application linked
  against LibTIFF when a specially crafted TIFF image is processed.
- Integer overflow in the TIFFFetchData function in tif_dirread.c allows
  context-dependent attackers to cause a denial of service and possibly
  execute arbitrary code via a crafted TIFF image.
- A double free error in tif_jpeg.c within the setfield/getfield methods
  in the cleanup functions can be exploited to crash an application linked
  against LibTIFF and may allow arbitrary code execution when a specially
  crafted TIFF image is processed.
- The TIFFToRGB function in libtiff allows remote attackers to cause a
  denial of service (crash) via a crafted TIFF image with Yr/Yg/Yb values
  that exceed the YCR/YCG/YCB values, which triggers an out-of-bounds read.

  The Common Vulnerabilities and Exposures project (cve.mitre.org) has
  assigned the names CVE-2006-2024, CVE-2006-2025, CVE-2006-2026 and
  CVE-2006-2120 these issues.

* Thu Jul 21 2005 Hasher Jamaludeen  <hasher at comodo dot com> 3.7.3-1tr
- New Upstream
- Security Fix: Stack-based buffer overflow in libTIFF allows remote
  attackers to execute arbitrary code via a TIFF file with a malformed
  BitsPerSample tag.

  The Common Vulnerabilities and Exposures project (cve.mitre.org) has
  assigned the name CAN-2005-1544.

* Fri Apr 08 2005 Ajith Thampi <ajith at comodo dot com> 3.7.2-1tr
- New Upstream
- Multiple Bug Fixes

* Thu Jan 06 2005 Ajith Thampi <ajith at comodo dot com> 3.7.1-1tr
- New Upstream
- spec cleanup
- CAN-2004-1183, CAN-2004-1308

* Tue Oct 12 2004 Oystein Viggen <oysteivi at trustix dot com> 3.6.1-1tr
- New upstream
- CAN-2004-0803, CAN-2004-0886

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 3.5.7-2tr
- Big rebuild

* Mon Apr 14 2003 Gerald Dachs <gda at trustix dot org> 3.5.7-1gd
- initial release
